# Ginear: Git + Linear Integration

🍸 Ginear is the perfect blend of Git and Linear, creating a seamless integration that allows you to attach or create Linear issues with automatic branch switching, all while playing on the spirit of "Gin."

Relies on [fzf](https://github.com/junegunn/fzf)
MacOS
`brew install fzf`
`pip install ginear`
